# from .main import *

# __copyright__    = 'Copyright (C) 2013 tiiday. All rights reserved'
# __version__      = '1.0.0'
# __license__      = ''
# __author__       = 'tiida'
# __author_email__ = 'tiida@Email'
# __url__          = 'http://github.com/account/repository'

# __all__ = ['公開モジュール', ...]




class tiida(object):
    def __init__(self):
        self.name = 'tiida'
        self.height = 178
        self.weight = 77

    def hello_tiida(self):
        print(f"hello {self.name}")
        return f"hello {self.name}"

def hello_tiida():
    print('hello tiida')



from setuptools import setup, find_packages

setup(
    name='hello_tiida',
    version='0.1',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'hello_tiida=hello_tiida.main:hello_tiida',
        ],
    },
)
